==> bitvec-0.1.0.crate: bitvec-0.1.0/CONTRIBUTING.md <==
# Contributing Guide

Contributions are absolutely welcome!

## Contact Information

In order of likelihood that I will actionably receive your contact, my
information is:

- [appayne@outlook.com](mailto:appayne@outlook.com)
- [@myrrlyn](//github.com/myrrlyn)
- [@myrrlyn](//twitter.com/myrrlyn)
- [@myrrlyn@cybre.space](//cybre.space/myrrlyn)
- [/u/myrrlyn](//reddit.com/u/myrrlyn)

I am not active on any IRC channels at this time. I am on Discord in the Rust
channel, so you may be able to reach me there, but I don’t know offhand how to
give out Discord profile links. I have a very consistent username scheme and so
anywhere you see my name, it’s *probably* me and I’ll *probably* respond to it.

## Preconditions

Be able to make a Rust project compile. I will happily help you learn how to do
this, but this particular crate is probably not something you want to explore as
a beginner.

Be comfortable using `U+0009 CHARACTER TABULATION` as your indentation setting.

That’s about it for prerequisites! This crate intends to power the lowest-level
of memory manipulation while also offering a convenient, powerful, and idiomatic
high-level API, so I encourage and welcome inputs on any aspect of this crate’s
construction. I know that I personally am much more capable at the low end than
the high, and so the user-facing API may not be as strong as it should be.

## Contributing

If you have a patch you think is worth inspecting right away, opening a pull
request without prelude is fine, although I would certainly appreciate an
accompanying explanation of what the patch does and why.

If you have questions, bugs, suggestions, or other contributions of any kind
that do not immediately touch the codebase, you can reach me informally to talk
about them or open an issue.

I will do my best to respond to all contacts in a timely manner.

==> bitvec-0.15.1.crate: bitvec-0.15.1/CONTRIBUTING.md <==
# Contributing Guide

Contributions are absolutely welcome!

## Contact Information

In order of likelihood that I will actionably receive your contact, my
information is:

- [self@myrrlyn.dev](mailto:self@myrrlyn.dev)
- [@myrrlyn](//github.com/myrrlyn)
- [@myrrlyn](//twitter.com/myrrlyn)
- [@myrrlyn@cybre.space](//cybre.space/myrrlyn)
- [/u/myrrlyn](//reddit.com/u/myrrlyn)

I am not active on any IRC channels at this time. I am on Discord in the Rust
channel, so you may be able to reach me there, but I don’t know offhand how to
give out Discord profile links. I have a very consistent username scheme and so
anywhere you see my name, it’s *probably* me and I’ll *probably* respond to it.

## Preconditions

Be able to make a Rust project compile. I will happily help you learn how to do
this, but this particular crate is probably not something you want to explore as
a beginner.

Be comfortable using `U+0009 CHARACTER TABULATION` as your indentation setting.

That’s about it for prerequisites! This crate intends to power the lowest level
of memory manipulation while also offering a convenient, powerful, and idiomatic
high-level API, so I encourage and welcome inputs on any aspect of this crate’s
construction. I know that I personally am much more capable at the low end than
the high, and so the user-facing API may not be as strong as it should be.

## Contributing

If you have a patch you think is worth inspecting right away, opening a pull
request without prelude is fine, although I would certainly appreciate an
accompanying explanation of what the patch does and why.

If you have questions, bugs, suggestions, or other contributions of any kind
that do not immediately touch the codebase, you can reach me informally to talk
about them or open an issue.

I will do my best to respond to all contacts in a timely manner.
